..  Copyright (C)  Brad Miller, David Ranum, Jeffrey Elkner, Peter Wentworth, Allen B. Downey, Chris
    Meyers, and Dario Mitchell.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".

.. qnum::
   :prefix: modules-4-
   :start: 1

Glossary
--------

.. glossary::

    deterministic
        A process that is repeatable and predictable.

    documentation
        A place where you can go to get detailed information about aspects of your
        programming language.


    module
        A file containing Python definitions and statements intended for use in
        other Python programs. The contents of a module are made available to
        the other program by using the *import* statement.

    namespace
        A naming system for making names unique, to avoid duplication and confusion. Within a namespace, no two names can be the same. 
        
    pseudo-random number
        A number that is not genuinely random but is instead created algorithmically.

    random number
        A number that is generated in such a way as to exhibit statistical randomness.

    random number generator
        A function that will provide you with random numbers, usually between 0 and 1.


    standard library
        A collection of modules that are part of the normal installation of Python.

